{*********************************************************}
{*          Web server application components            *}
{*                     version 2.0                       *}
{*         Copyright (c) 2000-2002  S.Perevoznyk         *}
{*                 All rights reserved.                  *}
{*********************************************************}
unit psvProducer;

interface

uses
  Windows,  SysUtils, Classes, Graphics, Controls,
  JPeg;

type

  TpsvCustomContentProducer = class(TComponent)
  public
    function Content: string; virtual;
  end;

  TpsvCountryProducer = class(TpsvCustomContentProducer)
  public
     function Content : string; override;
  end;

  TpsvImageProducer = class(TpsvCustomContentProducer)
  private
    FImageList : TImageList;
    FIndex : integer;
    procedure SetImageList(Value : TImageList);
  protected
     procedure Notification(AComponent: TComponent; Operation: TOperation); override;
  public
     function Content : string; override;
  published
    property ImageList : TImageList read FImageList write SetImageList;
    property Index : integer read FIndex write FIndex default 0;
  end;


procedure Register;

implementation


procedure Register;
begin
  RegisterComponents('FastWeb', [TpsvImageProducer, TpsvCountryProducer]);
end;

procedure TpsvImageProducer.Notification(AComponent: TComponent; Operation: TOperation);
begin
  inherited Notification(AComponent, Operation);
  if (Operation = opRemove) and (AComponent = FImageList) then
    FImageList := nil;
end;

procedure TpsvImageProducer.SetImageList(Value: TImageList);
begin
  if FImageList <> Value then
  begin
    if Value <> nil then Value.FreeNotification(Self);
    FImageList := Value;
  end;
end;


function TpsvImageProducer.Content : string;
var
  Jpg: TJpegImage;
  Bmp: TBitmap;
  OutStream : TStringStream;
begin
  OutStream := TStringStream.Create('');
    try
      Jpg    := TJpegImage.Create;
      Bmp := TBitmap.Create;

      if Assigned(FImageList) then
        FImageList.GetBitmap(FIndex,Bmp);

      try
        Jpg.Assign(Bmp);
        Jpg.SaveToStream(OutStream);
        Result := OutStream.DataString;
      finally
        Jpg.Free;
        Bmp.Free;
        OutStream.Free;
      end;
  except
    Result := '';
  end;
end;





const sCountryList : array[1..239] of string =
(
'Belgium',
'Afghanistan',
'Albania',
'Algeria',
'American Samoa',
'Andorra',
'Angola',
'Anguilla',
'Antarctica',
'Antigua and Barbuda',
'Argentina',
'Armenia',
'Aruba',
'Australia',
'Austria',
'Azerbaijan',
'Bahamas',
'Bahrain',
'Bangladesh',
'Barbados',
'Belarus',
'Belize',
'Benin',
'Bermuda',
'Bhutan',
'Bolivia',
'Bosnia and Herzegovina',
'Botswana',
'Bouvet Island',
'Brazil',
'British Indian Ocean Territory',
'Brunei Darussalam',
'Bulgaria',
'Burkina Faso',
'Burundi',
'Cambodia',
'Cameroon',
'Canada',
'Cape Verde',
'Cayman Islands',
'Central African Republic',
'Chad',
'Chile',
'China',
'Christmas Island',
'Cocos (Keeling) Islands',
'Colombia',
'Comoros',
'Congo',
'Cook Islands',
'Costa Rica',
'Cote D''voire (Ivory Coast)',
'Croatia (Hrvatska)',
'Cuba',
'Cyprus',
'Czech Republic',
'Denmark',
'Djibouti',
'Dominica',
'Dominican Republic',
'East Timor',
'Ecuador',
'Egypt',
'El Salvador',
'Equatorial Guinea',
'Eritrea',
'Estonia',
'Ethiopia',
'Falkland Islands (Malvinas)',
'Faroe Islands',
'Fiji',
'Finland',
'France',
'French Guiana',
'French Polynesia',
'French Southern Territories',
'Gabon',
'Gambia',
'Georgia',
'Germany',
'Ghana',
'Gibraltar',
'Greece',
'Greenland',
'Grenada',
'Guadeloupe',
'Guam',
'Guatemala',
'Guinea',
'Guinea-Bissau',
'Guyana',
'Haiti',
'Heard and McDonald Islands',
'Honduras',
'Hong Kong',
'Hungary',
'Iceland',
'India',
'Indonesia',
'Iran',
'Iraq',
'Ireland',
'Israel',
'Italy',
'Jamaica',
'Japan',
'Jordan',
'Kazakhstan',
'Kenya',
'Kiribati',
'Korea (North)',
'Korea (South)',
'Kuwait',
'Kyrgyzstan',
'Laos',
'Latvia',
'Lebanon',
'Lesotho',
'Liberia',
'Libya',
'Liechtenstein',
'Lithuania',
'Luxembourg',
'Macau',
'Macedonia',
'Madagascar',
'Malawi',
'Malaysia',
'Maldives',
'Mali',
'Malta',
'Marshall Islands',
'Martinpsvue',
'Mauritania',
'Mauritius',
'Mayotte',
'Mexico',
'Micronesia',
'Moldova',
'Monaco',
'Mongolia',
'Montserrat',
'Morocco',
'Mozambpsvue',
'Myanmar',
'Namibia',
'Nauru',
'Nepal',
'Netherlands',
'Netherlands Antilles',
'Neutral Zone',
'New Caledonia',
'New Zealand',
'Nicaragua',
'Niger',
'Nigeria',
'Niue',
'Norfolk Island',
'Northern Mariana Islands',
'Norway',
'Oman',
'Pakistan',
'Palau',
'Panama',
'Papua New Guinea',
'Paraguay',
'Peru',
'Philippines',
'Pitcairn',
'Poland',
'Portugal',
'Puerto Rico',
'Qatar',
'Reunion',
'Romania',
'Russian Federation',
'Rwanda',
'S. Georgia and S. Sandwich Isls.',
'Saint Kitts and Nevis',
'Saint Lucia',
'Saint Vincent and the Grenadines',
'Samoa',
'San Marino',
'Sao Tome and Principe',
'Saudi Arabia',
'Senegal',
'Seychelles',
'Sierra Leone',
'Singapore',
'Slovak Republic',
'Slovenia',
'Solomon Islands',
'Somalia',
'South Africa',
'Spain',
'Sri Lanka',
'St. Helena',
'St. Pierre and Mpsvuelon',
'Sudan',
'Suriname',
'Svalbard and Jan Mayen Islands',
'Swaziland',
'Sweden',
'Switzerland',
'Syria',
'Taiwan',
'Tajikistan',
'Tanzania',
'Thailand',
'Togo',
'Tokelau',
'Tonga',
'Trinidad and Tobago',
'Tunisia',
'Turkey',
'Turkmenistan',
'Turks and Caicos Islands',
'Tuvalu',
'US Minor Outlying Islands',
'Uganda',
'Ukraine',
'United Arab Emirates',
'United Kingdom',
'United States',
'Uruguay',
'Uzbekistan',
'Vanuatu',
'Vatican City State (Holy See)',
'Venezuela',
'Viet Nam',
'Virgin Islands (British)',
'Virgin Islands (U.S.)',
'Wallis and Futuna Islands',
'Western Sahara',
'Yemen',
'Yugoslavia',
'Zaire',
'Zambia',
'Zimbabwe'
);




function TpsvCountryProducer.Content : string;
var I : integer;
    St : string;
begin
St := '<SELECT NAME="Country">'+#10#13;
for i := 1 to 239 do
 St := St +'<option value="'+ScountryList[i]+'">'+SCountryList[i]+#10#13;
Result := St +'</SELECT></TD>';
end;

{ TpsvCustomContentProducer }

function TpsvCustomContentProducer.Content: string;
begin
  Result := '';
end;

end.
